==> ejc-laborsub-impl-3.0.1-20211125.074929-6-sources.jar: com/ejianc/business/sub/bean/RecordOtherCostEntity.java <==
package com.ejianc.business.sub.bean;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 分包记录其他费用实体
 * 
 * @author generator
 * 
 */
 @TableName("ejc_laborsub_contract_record_other_cost")
public class RecordOtherCostEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    /**
     * 序号
     */
    @TableField("tree_index")
    private String treeIndex;

    /**
     * 费用名称
     */
    @TableField("cost_name")
    private String costName;

    /**
     * 数量
     */
    @TableField("cost_num")
    private BigDecimal costNum;

    /**
     * 单价（无税）
     */
    @TableField("cost_price")
    private BigDecimal costPrice;

    /**
     * 税率
     */
    @TableField("cost_rate")
    private BigDecimal costRate;

    /**
     * 单价（含税）
     */
    @TableField("cost_price_with_tax")
    private BigDecimal costPriceWithTax;

    /**
     * 金额无税
     */
    @TableField("cost_amt")
    private BigDecimal costAmt;

    /**
     * 金额（含税）
     */
    @TableField("cost_amt_with_tax")
    private BigDecimal costAmtWithTax;

    /**
     * 税金
     */
    @TableField("cost_tax_amt")
    private BigDecimal costTaxAmt;

    /**
     * 备注
     */
    @TableField("cost_memo")
    private String costMemo;

    /**
     * 变更主键
     */
    @TableField("change_id")
    private Long changeId;

    /**
     * 变更子表主键
     */
    @TableField("change_bid")
    private Long changeBid;

    /**
     * 所属合同Id
     */
    @TableField("contract_id")
    private Long contractId;

    /**
     * 变更类型
     */
    @TableField("change_type")
    private Integer changeType;

    /**
     * 记录表ID
     */
    @TableField("record_id")
    private Long recordId;

    /**
     * 来源主合同子表id
     */
    @TableField("src_table_id")
    private Long srcTableId;

    public String getTreeIndex() {
        return treeIndex;
    }

    public void setTreeIndex(String treeIndex) {
        this.treeIndex = treeIndex;
    }

    public String getCostName() {
        return costName;
    }

    public void setCostName(String costName) {
        this.costName = costName;
    }

    public BigDecimal getCostNum() {
        return costNum;
    }

    public void setCostNum(BigDecimal costNum) {
        this.costNum = costNum;
    }

    public BigDecimal getCostPrice() {
        return costPrice;
    }

    public void setCostPrice(BigDecimal costPrice) {
        this.costPrice = costPrice;
    }

    public BigDecimal getCostRate() {
        return costRate;
    }

    public void setCostRate(BigDecimal costRate) {
        this.costRate = costRate;
    }

    public BigDecimal getCostPriceWithTax() {
        return costPriceWithTax;
    }

    public void setCostPriceWithTax(BigDecimal costPriceWithTax) {
        this.costPriceWithTax = costPriceWithTax;
    }

    public BigDecimal getCostAmt() {
        return costAmt;
    }

    public void setCostAmt(BigDecimal costAmt) {
        this.costAmt = costAmt;
    }

    public BigDecimal getCostAmtWithTax() {
        return costAmtWithTax;
    }

    public void setCostAmtWithTax(BigDecimal costAmtWithTax) {
        this.costAmtWithTax = costAmtWithTax;
    }

    public BigDecimal getCostTaxAmt() {
        return costTaxAmt;
    }

    public void setCostTaxAmt(BigDecimal costTaxAmt) {
        this.costTaxAmt = costTaxAmt;
    }

    public String getCostMemo() {
        return costMemo;
    }

    public void setCostMemo(String costMemo) {
        this.costMemo = costMemo;
    }

    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }

    public Long getChangeBid() {
        return changeBid;
    }

    public void setChangeBid(Long changeBid) {
        this.changeBid = changeBid;
    }

    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }

    public Integer getChangeType() {
        return changeType;
    }

    public void setChangeType(Integer changeType) {
        this.changeType = changeType;
    }

    public Long getRecordId() {
        return recordId;
    }

    public void setRecordId(Long recordId) {
        this.recordId = recordId;
    }

    public Long getSrcTableId() {
        return srcTableId;
    }

    public void setSrcTableId(Long srcTableId) {
        this.srcTableId = srcTableId;
    }
}

==> ejc-laborsub-impl-3.0.1-20211210.033208-29-sources.jar: com/ejianc/business/sub/bean/RecordOtherCostEntity.java <==
package com.ejianc.business.sub.bean;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 分包记录其他费用实体
 * 
 * @author generator
 * 
 */
 @TableName("ejc_laborsub_contract_record_other_cost")
public class RecordOtherCostEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    /**
     * 序号
     */
    @TableField("tree_index")
    private String treeIndex;

    /**
     * 费用名称
     */
    @TableField("cost_name")
    private String costName;

    /**
     * 数量
     */
    @TableField("cost_num")
    private BigDecimal costNum;

    /**
     * 单价（无税）
     */
    @TableField("cost_price")
    private BigDecimal costPrice;

    /**
     * 税率
     */
    @TableField("cost_rate")
    private BigDecimal costRate;

    /**
     * 单价（含税）
     */
    @TableField("cost_price_with_tax")
    private BigDecimal costPriceWithTax;

    /**
     * 金额无税
     */
    @TableField("cost_amt")
    private BigDecimal costAmt;

    /**
     * 金额（含税）
     */
    @TableField("cost_amt_with_tax")
    private BigDecimal costAmtWithTax;

    /**
     * 税金
     */
    @TableField("cost_tax_amt")
    private BigDecimal costTaxAmt;

    /**
     * 备注
     */
    @TableField("cost_memo")
    private String costMemo;

    /**
     * 变更主键
     */
    @TableField("change_id")
    private Long changeId;

    /**
     * 变更子表主键
     */
    @TableField("change_bid")
    private Long changeBid;

    /**
     * 所属合同Id
     */
    @TableField("contract_id")
    private Long contractId;

    /**
     * 变更类型
     */
    @TableField("change_type")
    private String changeType;

    /**
     * 记录表ID
     */
    @TableField("record_id")
    private Long recordId;

    /**
     * 来源主合同子表id
     */
    @TableField("src_table_id")
    private Long srcTableId;

    public String getTreeIndex() {
        return treeIndex;
    }

    public void setTreeIndex(String treeIndex) {
        this.treeIndex = treeIndex;
    }

    public String getCostName() {
        return costName;
    }

    public void setCostName(String costName) {
        this.costName = costName;
    }

    public BigDecimal getCostNum() {
        return costNum;
    }

    public void setCostNum(BigDecimal costNum) {
        this.costNum = costNum;
    }

    public BigDecimal getCostPrice() {
        return costPrice;
    }

    public void setCostPrice(BigDecimal costPrice) {
        this.costPrice = costPrice;
    }

    public BigDecimal getCostRate() {
        return costRate;
    }

    public void setCostRate(BigDecimal costRate) {
        this.costRate = costRate;
    }

    public BigDecimal getCostPriceWithTax() {
        return costPriceWithTax;
    }

    public void setCostPriceWithTax(BigDecimal costPriceWithTax) {
        this.costPriceWithTax = costPriceWithTax;
    }

    public BigDecimal getCostAmt() {
        return costAmt;
    }

    public void setCostAmt(BigDecimal costAmt) {
        this.costAmt = costAmt;
    }

    public BigDecimal getCostAmtWithTax() {
        return costAmtWithTax;
    }

    public void setCostAmtWithTax(BigDecimal costAmtWithTax) {
        this.costAmtWithTax = costAmtWithTax;
    }

    public BigDecimal getCostTaxAmt() {
        return costTaxAmt;
    }

    public void setCostTaxAmt(BigDecimal costTaxAmt) {
        this.costTaxAmt = costTaxAmt;
    }

    public String getCostMemo() {
        return costMemo;
    }

    public void setCostMemo(String costMemo) {
        this.costMemo = costMemo;
    }

    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }

    public Long getChangeBid() {
        return changeBid;
    }

    public void setChangeBid(Long changeBid) {
        this.changeBid = changeBid;
    }

    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }

    public String getChangeType() {
        return changeType;
    }

    public void setChangeType(String changeType) {
        this.changeType = changeType;
    }

    public Long getRecordId() {
        return recordId;
    }

    public void setRecordId(Long recordId) {
        this.recordId = recordId;
    }

    public Long getSrcTableId() {
        return srcTableId;
    }

    public void setSrcTableId(Long srcTableId) {
        this.srcTableId = srcTableId;
    }
}
